# encoding: utf-8

# *****************************************************************************
#
# (c) Copyright 2022 Micro Focus or one of its affiliates
#
# The only warranties for products and services of Micro Focus and its
# affiliates and licensors(Micro Focus) are as may be set forth in the
# express warranty statements accompanying such products and services.
# Nothing herein should be construed as constituting an additional warranty.
# Micro Focus shall not be liable for technical or editorial errors or
# omissions contained herein.
# The information contained herein is subject to change without notice.
#
# ******************************************************************************
# File:        include/umc/dialogs.rb
# Module:      Installation
# Summary:     Dialogs definitions
# Authors:     Gaurav Kumar <gaurav.kumar4@microfocus.com>
#              Srinidhi B <Srinidhi.BS@microfocus.com>
#

module Yast
  module UmcDialogsInclude
    def initialize_umc_dialogs(include_target)
      Yast.import "UI"

      textdomain "umc"

      Yast.import "Label"
      Yast.import "Wizard"
      Yast.import "Umc"
      Yast.import "EdirUtils"
      Yast.import "NovellUtils"
      Yast.import "NovellValidators"

      Yast.include include_target, "umc/complex.rb"
      Yast.include include_target, "umc/helps.rb"
    end

    def PromptIfNeededForEdirAdminPassword
      @useXad = Umc.useXad

      Builtins.y2milestone(
        "oes-umc.PromptIfNeededForEdirAdminPassword:use xad:%1",
        @useXad
      )

      if @useXad
        if Ops.get_string(NovellLDAP.Settings, "XAD_TREE_ADMIN_PASSWORD", "") == ""
          NovellLDAPUI.XadTreeAdminPasswordDialog
        end
      else
        if Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_ADMIN_PASSWORD", "") == ""
          NovellLDAPUI.AdminPasswordDialog
        end
      end

      @useXad
    end

    #UMC dialog
    def UmcDialog
      openPort = false
      dbPassword = Ops.get_string(Umc.Settings, "CONFIG_UMC_DB_PASSWORD", "")
      dbHostName = Ops.get_string(Umc.Settings, "CONFIG_UMC_DB_HOSTNAME", "")
      dbUserName = Ops.get_string(Umc.Settings, "CONFIG_UMC_DB_USERNAME", "")
      dbPort = Ops.get_string(Umc.Settings, "CONFIG_UMC_DB_PORT", "")

      if Ops.get_string(Umc.Settings, "CONFIG_UMC_OPEN_DB_PORT", "") == "yes"
        openPort = true
      end

      caption = _("OES Unified Management Console (UMC) Configuration")
      contents = VBox(
        VSpacing(0.5),
          Frame(
            _("Database Details"),
            VBox(
              VSpacing(0.25),
              HBox(
                TextEntry(
                  Id(:dbhostname),
                  Opt(:notify),
                  _("Hostname"),
                  dbHostName
                )
              ),
              HBox(
                HWeight(50,
                TextEntry(
                  Id(:dbport),
                  _("Port"),
                  dbPort
                )),
                HSpacing(1),
                HWeight(50,
                TextEntry(
                  Id(:dbusername),
                  _("Username"),
                  dbUserName
                ))
              ),
              HBox(
                HWeight(50,
                Password(
                  Id(:dbpassword),
                  _("Password"),
                  dbPassword
                )),
                HSpacing(1),
                HWeight(50,
                Password(
                  Id(:verifydbpassword),
                  _("Verify Password"),
                  ""
                ))
              ),
              Left(
                CheckBox(
                  Id(:openport),
                  Opt(:notify),
                  _("Open Port in Firewall"),
                  openPort
                )
              )
            )
          ),
          VStretch()
        )

      PromptIfNeededForEdirAdminPassword()
      Wizard.SetContentsButtons(
        caption,
        contents,
        Ops.get_string(@HELPS, "umc_config", ""),
        Label.BackButton,
        Label.NextButton
      )

      if Ops.get_string(Umc.Settings, "SERVICE_CONFIGURED", "") == "no" &&
        dbHostName == NovellUtils.GetDNSname
        UI.ChangeWidget(Id(:verifydbpassword), :Enabled, true)
      elsif Ops.get_string(Umc.Settings, "SERVICE_CONFIGURED", "") == "yes" ||
        dbHostName == Umc.existing_db_hostname
        UI.ChangeWidget(Id(:verifydbpassword), :Enabled, false)
      end

      ret = nil
      while true
        ret = UI.UserInput

        #read all values
        dbHostName = Convert.to_string(UI.QueryWidget(Id(:dbhostname), :Value))
        dbUserName = Convert.to_string(UI.QueryWidget(Id(:dbusername), :Value))
        dbPort = Convert.to_string(UI.QueryWidget(Id(:dbport), :Value))
        dbPassword = Convert.to_string(UI.QueryWidget(Id(:dbpassword), :Value))
        verifyPass = Convert.to_string(UI.QueryWidget(Id(:verifydbpassword), :Value))

        # abort?
        if ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        elsif ret == :dbhostname
          if dbHostName != Umc.existing_db_hostname
            UI.ChangeWidget(Id(:verifydbpassword), :Enabled, true)
          else
            UI.ChangeWidget(Id(:verifydbpassword), :Enabled, false)
          end
        elsif ret == :next
          #Validate Username
          if !ValidateDBUsername(dbUserName)
            next
          end

          #Validate Password
          if Ops.get_string(Umc.Settings, "SERVICE_CONFIGURED", "") == "no" &&
            dbHostName == NovellUtils.GetDNSname
            if !NovellValidators.ValidatePasswords(dbPassword, verifyPass)
              UI.ChangeWidget(Id(:dbpassword), :Value, "")
              UI.ChangeWidget(Id(:verifydbpassword), :Value, "")
              UI.SetFocus(Id(:dbpassword))
              next
            end
          end

          #Validate Dtabase Details
          if !ValidateDtabaseDetails(dbHostName, dbUserName, dbPort, dbPassword)
            next
          end

          Ops.set(Umc.Settings, "CONFIG_UMC_DB_HOSTNAME", dbHostName)
          Ops.set(Umc.Settings, "CONFIG_UMC_DB_PORT", dbPort)
          Ops.set(Umc.Settings, "CONFIG_UMC_DB_USERNAME", dbUserName)
          Ops.set(Umc.Settings, "CONFIG_UMC_DB_PASSWORD", dbPassword)

          if Convert.to_boolean(UI.QueryWidget(Id(:openport), :Value))
            Ops.set(Umc.Settings, "CONFIG_UMC_OPEN_DB_PORT", "yes")
          else
            Ops.set(Umc.Settings, "CONFIG_UMC_OPEN_DB_PORT", "no")
          end
          break
        elsif ret == :back
          break
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end
      deep_copy(ret)
    end

    def ValidateDBUsername(dbUserName)
      if Builtins.contains(dbUserName, ":") || Builtins.contains(dbUserName, "/")
        Popup.Message(_('Invalid Username. ":" and "/" are not allowed.'))
        return false
      end
      return true
    end
    def ValidateDtabaseDetails(dbHostName, dbUserName, dbPort, dbPassword)
      if dbHostName == "" || dbUserName == "" || dbPort == "" || dbPassword  == ""
        Popup.Message(_("Provide all the Database Details."))
        return false
      else
        # FIXME: Needed to add check for validating dtatbase, will work with arshad on this
        return true
      end
    end
  end
end
